import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextArea;
import javax.swing.SwingUtilities;

import com.mindfusion.drawing.SolidBrush;
import com.mindfusion.spreadsheet.standardforms.DialogResult;
import com.mindfusion.spreadsheet.CellRange;
import com.mindfusion.spreadsheet.ComparisonOperator;
import com.mindfusion.spreadsheet.ConditionalFormatType;
import com.mindfusion.spreadsheet.IConditionalFormat;
import com.mindfusion.spreadsheet.IRowStyle;
import com.mindfusion.spreadsheet.IStyle;
import com.mindfusion.spreadsheet.Measure;
import com.mindfusion.spreadsheet.TrackChangesCommand;
import com.mindfusion.spreadsheet.VerticalAlignment;
import com.mindfusion.spreadsheet.Workbook;
import com.mindfusion.spreadsheet.WorkbookView;
import com.mindfusion.spreadsheet.Worksheet;
import com.mindfusion.spreadsheet.WorksheetView;
import com.mindfusion.spreadsheet.standardforms.ConditionalFormatForm;


public class ConditionalFormats
{
	public static void main(String[] args)
	{			
		SwingUtilities.invokeLater(new Runnable()
		{
			public void run()
			{
				MainWindow window = new MainWindow();
				window.setTitle("JSpreadsheet Sample: Conditional Formats");
				window.setVisible(true);
			}
		});
	}
	
	public static class MainWindow extends JFrame
	{
		public MainWindow()
		{
			setDefaultCloseOperation(EXIT_ON_CLOSE);
			setSize(1280, 720);
			setLayout(new BorderLayout());
			
			
			Workbook workbook = new Workbook();
			Worksheet activeSheet = workbook.getWorksheets().add();

			WorkbookView wbView = new WorkbookView();
			wbView.setWorkbook(workbook);
			
			add(wbView, BorderLayout.CENTER);
			
			JPanel pnlComponents = new JPanel();
			pnlComponents.setLayout(new BorderLayout());
			add(pnlComponents, BorderLayout.SOUTH);
			
			JTextArea lblDescription = new JTextArea("Select rows, columns or cells and click the 'Conditional formats' button to add, edit and remove conditional formats for selected cells");
			lblDescription.setEditable(false);
			lblDescription.setEnabled(true);
			lblDescription.setLineWrap(true);
			lblDescription.setBackground(new Color(240, 240, 240));
			
			JPanel pnlLeft = new JPanel();
			pnlLeft.setLayout(new FlowLayout());
			pnlComponents.add(pnlLeft, BorderLayout.WEST);
			
			JPanel pnlBottom = new JPanel();
			pnlBottom.setLayout(new FlowLayout());
			pnlComponents.add(pnlBottom, BorderLayout.SOUTH);
			
			JPanel pnlRight = new JPanel();
			pnlRight.setLayout(new BorderLayout());
			JPanel pnlRRight = new JPanel();
			pnlRRight.setLayout(new FlowLayout());
			pnlRight.add(pnlRRight, BorderLayout.EAST);
			
			pnlComponents.add(lblDescription, BorderLayout.CENTER);
			
			JButton btnConditionalFormats = new JButton("Conditional formats");
			pnlComponents.add(pnlRight, BorderLayout.EAST);
			pnlRight.add(btnConditionalFormats, BorderLayout.CENTER);
			
			btnConditionalFormats.addActionListener(e->{
				ConditionalFormatForm cff = new ConditionalFormatForm(this, workbook, wbView.getActiveCell().getStyle());
				cff.setVisible(true);
				cff.addWindowListener(new WindowAdapter() {

					@Override
					public void windowClosed(WindowEvent e)
					{
						if(cff.getDialogResult() == DialogResult.OK)
						{
							CellRange range = wbView.getSelection().getRange();
							TrackChangesCommand c = workbook.startChangeOperation(wbView.getActiveWorksheet());
							IStyle st  = range.getStyle();
							cff.apply(st);
						}
					}

				});
			});
			
			
			
			//wbView.setFont(new Font("Calibri", Font.PLAIN, 11));

			// Create sample data
			String[] products = new String[]
			{
				"Chai",
				"Chang",
				"Aniseed Syrup",
				"Chef Anton's Cajun Seasoning",
				"Chef Anton's Gumbo Mix",
				"Grandma's Boysenberry Spread",
				"Uncle Bob's Organic Dried Pears",
				"Northwoods Cranberry Sauce",
				"Mishi Kobe Niku",
				"Ikura",
				"Queso Cabrales",
				"Queso Manchego La Pastora",
				"Konbu",
				"Tofu",
				"Genen Shouyu",
				"Pavlova",
				"Alice Mutton",
				"Carnarvon Tigers",
				"Teatime Chocolate Biscuits",
				"Sir Rodney's Marmalade",
			};

			String[] categories = new String[]
			{
				"Beverages",
				"Beverages",
				"Condiments",
				"Condiments",
				"Condiments",
				"Condiments",
				"Produce",
				"Condiments",
				"Meat/Poultry",
				"Seafood",
				"Dairy Products",
				"Dairy Products",
				"Seafood",
				"Produce",
				"Condiments",
				"Confections",
				"Meat/Poultry",
				"Seafood",
				"Confections",
				"Confections",
			};

			double[] prices = new double[]
			{
				11.5,
				38,
				25.45,
				16,
				21.95,
				19.85,
				31.45,
				44.5,
				21.85,
				1.65,
				0.8,
				9.95,
				11.5,
				14,
				13.5,
				8.9,
				21.9,
				6.75,
				4.3,
				17.6,
			};

			int lastColumn = activeSheet.getColumns().getCount() - 1;
			int lastRow = activeSheet.getRows().getCount() - 1;
			IStyle style = activeSheet.getCellRanges().get(0, 0, lastColumn, lastRow).getStyle();
			style.setFontName("Calibri");
			style.setFontSize(14.0);
			style.setPaddingLeft(new Measure("3pt"));
			style.setPaddingTop(new Measure("3pt"));
			style.setPaddingRight(new Measure("3pt"));
			style.setPaddingBottom(new Measure("3pt"));
			style.setVerticalAlignment(VerticalAlignment.Middle);
			IRowStyle rowStyle = activeSheet.getRows().get(0, lastRow).getStyle();
			rowStyle.setHeight(new Measure("17pt"));

			activeSheet.beginInit();

			activeSheet.getCells().get(1, 2).setData("Product");
			activeSheet.getCells().get(2, 2).setData("Category");
			activeSheet.getCells().get(3, 2).setData("Price");

			for (int i = 0; i < products.length; i++)
				activeSheet.getCells().get(1, i + 3).setData(products[i]);
			for (int i = 0; i < categories.length; i++)
				activeSheet.getCells().get(2, i + 3).setData(categories[i]);
			for (int i = 0; i < prices.length; i++)
				activeSheet.getCells().get(3, i + 3).setData(prices[i]);

			IStyle titleStyle = activeSheet.getCellRanges().get(1, 2, 3, 2).getStyle();
			titleStyle.setFontBold(true);
			titleStyle.setBackground(new SolidBrush(new Color (50, 205, 50)));
			IStyle categoriesStyle = activeSheet.getCellRanges().get(2, 3, 2, 22).getStyle();
			IStyle pricesStyle = activeSheet.getCellRanges().get(3, 3, 3, 22).getStyle();
			pricesStyle.setFontBold(true);
			pricesStyle.setFormat("#,##0.00;(#,##0.00)");

			// Set some conditional formats
			IConditionalFormat format1 = pricesStyle.getConditionalFormats().add();
			format1.setType(ConditionalFormatType.CellValue);
			format1.setOperator(ComparisonOperator.GreaterThan);
			format1.setSecond("20");
			format1.getStyle().setBackground(new SolidBrush(new Color(255, 120, 85)));

			IConditionalFormat format2 = categoriesStyle.getConditionalFormats().add();
			format2.setType(ConditionalFormatType.CellValue);
			format2.setOperator(ComparisonOperator.Contain);
			format2.setFirst("Condiments");
			format2.getStyle().setTextColor(new Color(215, 186, 116));
			format2.getStyle().setFontItalic(true);

			wbView.resizeColumnsToFit(1, 3);

			activeSheet.endInit();
		}

		private static final long serialVersionUID = 1L;
	}
}